@@ -7,9 +7,11 @@ See Also
 
 
 from typing import Optional
+from typing import Union
 
 from apyscript.color import color_util
 from apyscript.converter import cast
+from apyscript.type.number import Number
 from apyscript.validation import color_validation
 from apyscript.validation import number_validation
 
@@ -17,9 +19,11 @@ from apyscript.validation import number_validation
 class BiginFillInterface:
 
     _fill_color: Optional[str] = None
-    _fill_alpha: Optional[float] = None
+    _fill_alpha: Optional[Number] = None
 
-    def begin_fill(self, color: str, alpha: float = 1.0) -> None:
+    def begin_fill(
+            self, color: str,
+            alpha: Union[float, Number] = 1.0) -> None:
         """
         Set single color value for fill.
 
@@ -27,15 +31,18 @@ class BiginFillInterface:
         ----------
         color : str
             Hexadecimal color string. e.g., '#00aaff'
-        alpha : float, default 1.0
+        alpha : float or Number, default 1.0
             Color opacity (0.0 to 1.0).
         """
         color = color_util.complement_hex_color(hex_color_code=color)
         self._fill_color = color
         number_validation.validate_num(num=alpha)
-        alpha = cast.to_float_from_int(int_or_float=alpha)
+        if not isinstance(alpha, Number):
+            alpha = cast.to_float_from_int(int_or_float=alpha)
+        else:
+            alpha = alpha.value
         color_validation.validate_alpha_range(alpha=alpha)
-        self._fill_alpha = alpha
+        self._fill_alpha = Number(value=alpha)
 
     @property
     def fill_color(self) -> Optional[str]:
@@ -51,13 +58,13 @@ class BiginFillInterface:
         return self._fill_color
 
     @property
-    def fill_alpha(self) -> Optional[float]:
+    def fill_alpha(self) -> Optional[Number]:
         """
         Get current fill color opacity.
 
         Returns
         -------
-        fill_alpha : float or None
+        fill_alpha : Number or None
             Current fill color opacity (0.0 to 1.0).
             If not be set, None will be returned.
         """
