@@ -434,3 +434,113 @@ class NumberValueInterface(CopyInterface):
         """
         result: NumberValueInterface = self / other
         return result
+
+    def __str__(self) -> str:
+        """
+        String cast method.
+
+        Returns
+        -------
+        string : str
+            Casted value string.
+        """
+        return str(self.value)
+
+    def __eq__(self, other: Any) -> bool:
+        """
+        Equal comparison method.
+
+        Parameters
+        ----------
+        other : *
+            Other value to compare. Builtin types, Int,
+            and Number class instances are acceptable.
+
+        Returns
+        -------
+        result : bool
+            If specified value is same amount, True will be returned.
+        """
+        if isinstance(other, NumberValueInterface):
+            return self.value == other.value
+        return self.value == other
+
+    def __lt__(self, other: Any) -> bool:
+        """
+        Less than comparison method.
+
+        Parameters
+        ----------
+        other : *
+            Other value to compare. Builtin types, Int,
+            and Number class instances are acceptable.
+
+        Returns
+        -------
+        result : bool
+            If this value is less than a specified value, then
+            True will be returned.
+        """
+        if isinstance(other, NumberValueInterface):
+            return self.value < other.value
+        return self.value < other
+
+    def __le__(self, other: Any) -> bool:
+        """
+        Less than equal comparison method.
+
+        Parameters
+        ----------
+        other : *
+            Other value to compare. Builtin types, Int,
+            and Number class instances are acceptable.
+
+        Returns
+        -------
+        result : bool
+            If this value is less than or equal to a specified value,
+            then True will be returned.
+        """
+        if isinstance(other, NumberValueInterface):
+            return self.value <= other.value
+        return self.value <= other
+
+    def __gt__(self, other: Any) -> bool:
+        """
+        Greater than comparison method.
+
+        Parameters
+        ----------
+        other : *
+            Other value to compare. Builtin types, Int,
+            and Number class instances are acceptable.
+
+        Returns
+        -------
+        result : bool
+            If this value is greater than a specified value, then
+            True will be returned.
+        """
+        if isinstance(other, NumberValueInterface):
+            return self.value > other.value
+        return self.value > other
+
+    def __ge__(self, other: Any) -> bool:
+        """
+        Greater than equal comparison method.
+
+        Parameters
+        ----------
+        other : *
+            Other value to compare. Builtin types, Int,
+            and Number class instances are acceptable.
+
+        Returns
+        -------
+        result : bool
+            If this value is greater than or equal to a specified value,
+            then True will be returned.
+        """
+        if isinstance(other, NumberValueInterface):
+            return self.value >= other.value
+        return self.value >= other
